@@ -9,6 +9,8 @@ void register_cuda_quiver_sample(pybind11::module &m);
 
 void register_cuda_quiver_feature(pybind11::module &m);
 
+void register_cuda_quiver_comm(pybind11::module &m);
+
 void register_cpu_quiver(pybind11::module &m);
 
 PYBIND11_MODULE(TORCH_EXTENSION_NAME, m)
@@ -19,5 +21,6 @@ PYBIND11_MODULE(TORCH_EXTENSION_NAME, m)
 #ifdef HAVE_CUDA
     register_cuda_quiver_sample(m);
     register_cuda_quiver_feature(m);
+    register_cuda_quiver_comm(m);
 #endif
 }
